@@ -73,6 +73,15 @@ def snowflake_engine_factory(
             "WAREHOUSE": "SNOWFLAKE_TRANSFORM_WAREHOUSE",
             "ROLE": "TRANSFORMER",
         },
+        # Note: This Bizible user is used for extracting data from Bizible
+        "BIZIBLE_USER": {
+            "USER": "BIZIBLE_SNOWFLAKE_USER",
+            "PASSWORD": "BIZIBLE_SNOWFLAKE_PASSWORD",
+            "ACCOUNT": "BIZIBLE_SNOWFLAKE_ACCOUNT",
+            "DATABASE": "BIZIBLE_SNOWFLAKE_DATABASE",
+            "WAREHOUSE": "BIZIBLE_SNOWFLAKE_WAREHOUSE",
+            "ROLE": "BIZIBLE_SNOWFLAKE_ROLE",
+        },
     }
 
     vars_dict = role_dict[role]
@@ -210,6 +219,7 @@ def dataframe_uploader(
     table_name: str,
     schema: str = None,
     advanced_metadata: bool = False,
+    if_exists: str = "append",
 ) -> None:
     """
     Upload a dataframe, adding in some metadata and cleaning up along the way.
@@ -220,7 +230,7 @@ def dataframe_uploader(
         con=engine,
         schema=schema,
         index=False,
-        if_exists="append",
+        if_exists=if_exists,
         chunksize=10000,
     )
 
@@ -231,7 +241,8 @@ def snowflake_stage_load_copy_remove(
     table_path: str,
     engine: Engine,
     type: str = "json",
-    on_error="skip_file",
+    on_error: str = "skip_file",
+    file_format_options: str = "",
 ) -> None:
     """
     Upload file to stage, copy to table, remove file from stage on Snowflake
@@ -239,12 +250,24 @@ def snowflake_stage_load_copy_remove(
 
     put_query = f"put file://{file} @{stage} auto_compress=true;"
 
-    copy_query = f"""copy into {table_path} (jsontext)
-                     from @{stage}
-                     file_format=(type='{type}'),
-                     on_error='{on_error}';"""
+    if type == "json":
+        copy_query = f"""copy into {table_path} (jsontext)
+                         from @{stage}
+                         file_format=(type='{type}'),
+                         on_error='{on_error}';"""
 
-    remove_query = f"remove @{stage} pattern='.*.{type}.gz'"
+        remove_query = f"remove @{stage} pattern='.*.{type}.gz'"
+    else:
+        file_name = os.path.basename(file)
+        file_pattern = f".*{file_name}.gz"
+        copy_query = f"""copy into {table_path} 
+                         from @{stage}
+                         file_format=(type='{type}' {file_format_options}),
+                         on_error='{on_error}'
+                         pattern='{file_pattern}';
+                        """
+
+        remove_query = f"remove @{stage} pattern='{file_pattern}'"
 
     logging.basicConfig(stream=sys.stdout, level=20)
 
@@ -253,11 +276,11 @@ def snowflake_stage_load_copy_remove(
 
         logging.info(f"Clearing {type} files from stage.")
         remove = connection.execute(remove_query)
-        logging.info(remove)
+        logging.info(f"Query successfully run")
 
         logging.info("Writing to Snowflake.")
         results = connection.execute(put_query)
-        logging.info(results)
+        logging.info(f"Query successfully run")
     finally:
         connection.close()
         engine.dispose()
@@ -267,11 +290,11 @@ def snowflake_stage_load_copy_remove(
 
         logging.info(f"Copying to Table {table_path}.")
         copy_results = connection.execute(copy_query)
-        logging.info(copy_results)
+        logging.info(f"Query successfully run")
 
         logging.info(f"Removing {file} from stage.")
         remove = connection.execute(remove_query)
-        logging.info(remove)
+        logging.info(f"Query successfully run")
     finally:
         connection.close()
         engine.dispose()
